@@ -50,7 +50,8 @@ class Task:
                 bar.refresh()
             if self.task_state == FAILURE:
                 self.update(include_result=True)
-                raise Exception("ERROR for task {}: {}".format(self.task_id, self.task_result))
+                npu_print(f"Error for task {self.task_id}: {self.task_result}", level="ERROR")
+                exit(1)
             if self.task_state == STOPPED:
                 npu_print("Task has been stopped.")
                 return
