@@ -4,7 +4,7 @@ import dill
 
 from .Task import Task
 from .common import getToken, check_data, add_kwargs_to_params, check_model, determine_data, check_model_type, \
-    check_data_type, get_project, npu_print, post
+    check_data_type, get_project, npu_print, post, HubDataset
 from .web.urls import TRAIN_URL
 
 
@@ -45,6 +45,8 @@ def train_api(model, train_data, val_data, train_kwargs, val_kwargs, batch_size,
     check_model_type(model, params)
     check_data_type(train_data, "train", params)
     check_data_type(val_data, "test", params)
+    params["train_hub_ds"] = isinstance(train_data, HubDataset)
+    params["test_hub_ds"] = isinstance(val_data, HubDataset)
     params = add_kwargs_to_params(params, **kwargs)
     response = post(TRAIN_URL, json=params)
     if response.status_code != 200:
