@@ -16,7 +16,7 @@ def api(token="", project="Default", verbosity=1, deployed=False):
     core.api(token, project, verbosity, deployed)
 
 
-def compile(model, input_shape=None, library="", model_label="", asynchronous=False):
+def compile(model, input_shape=None, library="", model_label="", scripts=None, input_kwargs=None, asynchronous=False):
     """Use this to upload and compile your model. Compatible frameworks are:
 
         * Pytorch
@@ -38,7 +38,11 @@ def compile(model, input_shape=None, library="", model_label="", asynchronous=Fa
     """
     if input_shape is None:
         input_shape = []
-    return core.compile(model, input_shape, library, model_label, asynchronous)
+    if scripts is None:
+        scripts = []
+    if input_kwargs is None:
+        input_kwargs = {}
+    return core.compile(model, input_shape, library, model_label, scripts, input_kwargs, asynchronous)
 
 
 def upload_data(data, name=""):
